@@ -1,23 +1,21 @@
-fstep.fisher <-
-function(Y,T,kernel){
-
-	n = nrow(Y)
-	p = ncol(Y)
+fstep.fisher <- function(XX,T,S,kernel){
+	n = nrow(XX)
+	p = ncol(XX)
 	K = ncol(T)
-	m = colMeans(Y)
+	#m = colMeans(Y)
 	d = min(p-1,(K-1))
 
 	# Compute S
-	XX = as.matrix(Y - t(m*t(matrix(1,n,p))))
+	#XX = as.matrix(Y - t(m*t(matrix(1,n,p))))
 	TT = t(apply(T,1,"/",sqrt(colSums(T))))
 	
 	if (n>p & kernel==''){
-		S = t(XX) %*% XX /n
+		#S = t(XX) %*% XX /n
 		B = t(XX)%*%TT%*%t(TT)%*%XX / n
 	
 		# Eigendecomposition of S^-1 * B
-		
-		eig = svd(ginv(S)%*%B,nu=d,nv=0) # no sparse case
+		eig = svd(ginv(S)%*%B,nu=d,nv=0)
+		#eig = svds(ginv(S)%*%B,d,nu=d,nv=0)
 		U   = eig$u[,1:d]
 	}
 	else{
@@ -28,8 +26,8 @@ function(Y,T,kernel){
 		S = G %*% G + lambda*diag(n)
 		B = G %*% TT %*% t(TT) %*% G
 		H = svd(ginv(S)%*%B,nu=d,nv=0)$u[,1:d]
-		U = svd(t(Y) %*% H,nu=d,nv=0)$u[,1:d]
+		U = svd(t(XX) %*% H,nu=d,nv=0)$u[,1:d]
 	}
-        as.matrix(U)
+  return(as.matrix(U))
 }
 
